@@ -165,7 +165,7 @@
 #' }
 #' @export
 eval_tidy <- function(expr, data = NULL, env = caller_env()) {
-  .Call(rlang_eval_tidy, expr, data, env)
+  .External2(rlang_ext2_eval_tidy, expr, data, env)
 }
 
 # Helps work around roxygen loading issues
@@ -219,6 +219,7 @@ print.rlang_fake_data_pronoun <- function(...) cat_line("<pronoun>")
 #' @export
 .data <- structure(list(), class = "rlang_fake_data_pronoun")
 #' @rdname tidyeval-data
+#' @format NULL
 #' @export
 .env <- .data
 
