@@ -53,10 +53,7 @@ new_formula <- function(lhs, rhs, env = caller_env()) {
 #' is_bare_formula(f, scoped = TRUE)
 #' is_bare_formula(eval(f), scoped = TRUE)
 is_formula <- function(x, scoped = NULL, lhs = NULL) {
-  if (!is_formulaish(x, scoped = scoped, lhs = lhs)) {
-    return(FALSE)
-  }
-  identical(node_car(x), tilde_sym)
+  .Call(rlang_is_formula, x, scoped, lhs)
 }
 #' @rdname is_formula
 #' @export
@@ -166,7 +163,7 @@ f_env <- function(f) {
   if (!is_formula(x)) {
     abort("`f` must be a formula")
   }
-  set_attrs(x, .Environment = value)
+  structure(x, .Environment = value)
 }
 
 #' Turn RHS of formula into a string or label
@@ -206,7 +203,7 @@ f_label <- function(x) {
 
 
 signal_formula_access <- function() {
-  if (is_true(peek_option("rlang_internal_warn_quosure_access"))) {
+  if (is_true(peek_option("rlang:::warn_quosure_access"))) {
     warn(
       "Using formula accessors with quosures is soft-deprecated"
     )
