@@ -376,13 +376,13 @@ test_that("can inspect the exported pronoun", {
   expect_output(print(rlang::.data), "<pronoun>")
 })
 
-test_that("data pronoun always skips functions", {
+test_that("data pronoun doesn't skip functions (#1061, #5608)", {
   top <- env(c = "c")
   bottom <- env(top, c = base::c)
   mask <- new_data_mask(bottom, top)
 
   .data <- as_data_pronoun(mask)
-  expect_identical(.data$c, "c")
+  expect_identical(.data$c, base::c)
 })
 
 test_that("leaked quosure masks are not mistaken with data masks", {
@@ -461,13 +461,23 @@ test_that(".data pronoun handles promises (#908)", {
   expect_equal(eval_tidy(expr(.data$a * 2), mask), 2)
 })
 
-# Lifecycle ----------------------------------------------------------
-
-test_that("as_data_mask() and new_data_mask() are deprecated", {
-  expect_defunct(as_data_mask(mtcars, env()))
-  expect_defunct(new_data_mask(NULL, NULL, parent = env()))
+test_that("can evaluate tilde in nested masks", {
+  tilde <- eval_tidy(quo(eval_tidy(~1)))
+  expect_identical(
+    eval_bare(tilde, f_env(tilde)),
+    tilde
+  )
 })
 
+test_that("eval_tidy() propagates visibility", {
+  expect_visible(eval_tidy(quo(list(invisible(list())))))
+  expect_invisible(eval_tidy(quo(invisible(list()))))
+  expect_invisible(eval_tidy(quo(identity(!!local(quo(invisible(list())))))))
+})
+
+
+# Lifecycle ----------------------------------------------------------
+
 test_that("supplying environment as data is deprecated", {
   local_options(lifecycle_verbose_soft_deprecation = TRUE)
   `_x` <- "foo"
