@@ -1,6 +1,6 @@
 context("retired")
 
-scoped_lifecycle_silence()
+local_lifecycle_silence()
 
 
 # Deprecated in rlang 0.4.0 ------------------------------------------
@@ -498,7 +498,7 @@ test_that("finds correct env type - frame", {
 })
 
 test_that("retired _len() ctors still work", {
-  scoped_options(lifecycle_verbose_soft_deprecation = FALSE)
+  local_options(lifecycle_verbose_soft_deprecation = FALSE)
   expect_identical(lgl_len(2), new_logical(2))
   expect_identical(int_len(2), new_integer(2))
   expect_identical(dbl_len(2), new_double(2))
@@ -510,7 +510,7 @@ test_that("retired _len() ctors still work", {
 })
 
 test_that("retired _along() ctors still work", {
-  scoped_options(lifecycle_verbose_soft_deprecation = FALSE)
+  local_options(lifecycle_verbose_soft_deprecation = FALSE)
   expect_identical(lgl_along(1:2), new_logical_along(1:2))
   expect_identical(int_along(1:2), new_integer_along(1:2))
   expect_identical(dbl_along(1:2), new_double_along(1:2))
@@ -522,7 +522,7 @@ test_that("retired _along() ctors still work", {
 })
 
 test_that("whole scope is purged", {
-  scoped_options(lifecycle_verbose_soft_deprecation = FALSE)
+  local_options(lifecycle_verbose_soft_deprecation = FALSE)
 
   outside <- child_env(NULL, important = TRUE)
   top <- child_env(outside, foo = "bar", hunoz = 1)
@@ -544,10 +544,6 @@ test_that("whole scope is purged", {
   expect_identical(names(outside), "important")
 })
 
-test_that("pattern match on string encoding", {
-  expect_defunct(is_character(letters, encoding = "unknown"))
-})
-
 test_that("vector _along() ctors pick up names", {
   x <- list(a = NULL, b = NULL)
   expect_identical(new_logical_along(x), c(a = NA, b = NA))
